@@ -26,7 +26,7 @@ convert_df <- function(x) {
             x[[i]] <- NA
         }
     }
-    as.data.frame(x)
+    data.frame(x, stringsAsFactors = FALSE)
 }
 
 # election date entry
@@ -37,12 +37,3 @@ electiondate2date <- function(x) {
         as.Date(x, "%Y-%m-%d")
     }
 }
-
-factors2char <- function(x) {
-    for (i in names(x)) {
-        if (is(x[[i]], "factor")) {
-            x[[i]] <- as.character(x[[i]])
-        }
-    }
-    x
-}
